{ "@context": "https://schema.org", "@type": "SoftwareApplication", "name": "eSTZwritR", "alternateName": "easy rider", "applicationCategory": "Scientific Software", "operatingSystem": "Windows, macOS, Linux", "softwareVersion": "0.1.1", "description": "R package for applying standardized file naming, directory structure, and mapping conventions to empirical Seed Transfer Zones (eSTZs) in the United States to streamline data sharing among natural resource professionals.", "url": "https://sagesteppe.github.io/eSTZwritR/", "downloadUrl": "https://github.com/sagesteppe/eSTZwritR", "codeRepository": "https://github.com/sagesteppe/eSTZwritR", "author": [ { "@type": "Person", "name": "Brianna Wieferich" }, { "@type": "Person", "name": "Reed Benkendorf", "url": "https://github.com/sagesteppe" } ], "programmingLanguage": "R", "keywords": [ "seed transfer zones", "eSTZ", "empirical seed zones", "native plant restoration", "germplasm", "seed collection", "ecological genetics", "restoration ecology", "spatial data", "R package", "data standards" ], "inLanguage": "en-US", "citation": { "@type": "ScholarlyArticle", "name": "Empirical seed transfer zones require conventions for data sharing to increase their utilization by practitioners", "author": [ {"@type": "Person", "name": "Brianna Wieferich"}, {"@type": "Person", "name": "Reed Benkendorf"} ], "datePublished": "??", "publisher": "??", "url": "https://github.com/sagesteppe/EmpiricalSeedZones/blob/main/manuscript/Empirical-seed-transfer-zones-require-conventions-for-data-sharing-to-increase-their-utilization-by-practitioners.pdf" }, "offers": { "@type": "Offer", "price": "0", "priceCurrency": "USD" }, "sameAs": [ "https://doi.org/10.5281/zenodo.14641975" ] }

Skip to contents

Create a directory following standard conventions to ensure appropriate placement of subdirectories and naming conventions.

Usage

dirmakR(outpath, sci_name, x, nrcs_code, regioncode, overwrite, estz_type)

Arguments

outpath

the directory folder where the final products will be placed. Note there is no need to create an independent folder to hold them, this will be included in the product.

sci_name

the scientific name of the taxon

x

Vector data product.

nrcs_code

from https://plants.usda.gov/

regioncode

a character vector string of the name for this or, the output from regioncoding

overwrite

whether to overwrite the existing directory (if it already exists)

estz_type

one of 'lg' for landscape genetics (or genetic), 'cg' for common garden, or 'cm' for climate matched. If multiple approaches choose the most robust method, e.g. 'cg' > 'lg' > 'cm'

Examples

if (FALSE) { # \dontrun{
acth7 <- sf::st_read(file.path(
  system.file(package="eSTZwritR"), "extdata", 'ACTH7.gpkg')
)
dirmakR('.',
  'Eriocoma thurberiana',
   acth7,
   nrcs_code = 'ACHT7',
   regioncode =  'CGB-CPN',
   estz_type = 'cg'
   )
} # }