{ "@context": "https://schema.org", "@type": "SoftwareApplication", "name": "eSTZwritR", "alternateName": "easy rider", "applicationCategory": "Scientific Software", "operatingSystem": "Windows, macOS, Linux", "softwareVersion": "0.1.1", "description": "R package for applying standardized file naming, directory structure, and mapping conventions to empirical Seed Transfer Zones (eSTZs) in the United States to streamline data sharing among natural resource professionals.", "url": "https://sagesteppe.github.io/eSTZwritR/", "downloadUrl": "https://github.com/sagesteppe/eSTZwritR", "codeRepository": "https://github.com/sagesteppe/eSTZwritR", "author": [ { "@type": "Person", "name": "Brianna Wieferich" }, { "@type": "Person", "name": "Reed Benkendorf", "url": "https://github.com/sagesteppe" } ], "programmingLanguage": "R", "keywords": [ "seed transfer zones", "eSTZ", "empirical seed zones", "native plant restoration", "germplasm", "seed collection", "ecological genetics", "restoration ecology", "spatial data", "R package", "data standards" ], "inLanguage": "en-US", "citation": { "@type": "ScholarlyArticle", "name": "Empirical seed transfer zones require conventions for data sharing to increase their utilization by practitioners", "author": [ {"@type": "Person", "name": "Brianna Wieferich"}, {"@type": "Person", "name": "Reed Benkendorf"} ], "datePublished": "??", "publisher": "??", "url": "https://github.com/sagesteppe/EmpiricalSeedZones/blob/main/manuscript/Empirical-seed-transfer-zones-require-conventions-for-data-sharing-to-increase-their-utilization-by-practitioners.pdf" }, "offers": { "@type": "Offer", "price": "0", "priceCurrency": "USD" }, "sameAs": [ "https://doi.org/10.5281/zenodo.14641975" ] }

Skip to contents

Appropriately order the fields of a shapefile and ensure consistent naming of them.

Usage

fieldsmakR(x, SeedZone, ID, SZName, AreaAcres)

Arguments

x

an sf/tibble/dataframe containing the spatial data which will be distributed as a final product

SeedZone

Character. Column name containing the numeric SeedZone code, if not supplied function will fail.

ID

Character. Columm name specifying this columns names, If not supplied will create one.

SZName

Character. Column name containing a name for the SeedZone column to be used in conversation, such as 'Productivity high, Phenology late' or 'SW midmontane', if not supplied will copy 'SeedZone' column values

AreaAcres

Chacter. Column name containing the name for the column containing an area measurement, if not supplied this value will be calculated using epsg:5070

Examples

if (FALSE) { # \dontrun{
df <- data.frame(
  id = 1:10,
  gridcode = sample(1:10, replace = FALSE),
  zone = sample(LETTERS, 10, replace = FALSE),
  bio1_sd = runif(10, 5, 7),
  bio8_mean = runif(10, 5, 7)
)

nc <- sf::st_read(system.file("shape/nc.shp", package="sf"), quiet = TRUE) |>
 dplyr::select(geometry) |>
 dplyr::slice_head(n = 10) |>
 dplyr::bind_cols(df, )

ob <- fieldsmakR(nc, SeedZone = 'gridcode')

dplyr::select(ob, -zone) # easily remove like so.
} # }